==> qcad-3.15.5.3.tgz: lib/qcad/ts/qcadgui_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Neveljavno</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/ts/qcadgui_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Prilagojeno</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Mreža</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Na entiteti</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Pravokotno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangencialno</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Sredina</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Presečišče</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referenca</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Neveljavno</translation>
    </message>
</context>
</TS>
